#
# spec file for package gdb
#
# Copyright (c) 2011 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Summary:        The GNU Debugger

Name:           gdb

# Set version to contents of gdb/version.in.
# NOTE: the FSF gdb versions are numbered N.M for official releases, like 6.3
# and, since January 2005, X.Y.Z.date for daily snapshots, like 6.3.50.20050112 # (daily snapshot from mailine), or 6.3.0.20040112 (head of the release branch).
Version:        7.1
Release:        8.9.1

# The release always contains a leading reserved number, start it at 1.
# `upstream' is not a part of `name' to stay fully rpm dependencies compatible for the testing.

License:        GPL v2 or later
Group:          Development/Tools/Debuggers
# Do not provide URL for snapshots as the file lasts there only for 2 days.
# ftp://sourceware.org/pub/gdb/snapshots/branch/gdb-%{version}.tar.bz2
# ftp://sourceware.org/pub/gdb/releases/gdb-%{version}.tar.bz2
Source:         ftp://sourceware.org/pub/gdb/releases/gdb-%{version}.tar.bz2
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Url:            http://www.gnu.org/software/gdb/

# For our convenience
%define gdb_src gdb-%{version}
%define gdb_build build-%{_target_platform}

%if 0%{?_with_debug:1}
# Define this if you want to skip the strip step and preserve debug info.
# Useful for testing.
%define __debug_install_post : > %{_builddir}/%{?buildsubdir}/debugfiles.list
%define debug_package %{nil}
%endif

# Make sure we get rid of the old package gdb64, now that we have unified
# support for 32-64 bits in one single 64-bit gdb.
%ifarch ppc64
Obsoletes:      gdb64 < 5.3.91
%endif

# GDB patches have the format `gdb-<version>-bz<red-hat-bz-#>-<desc>.patch'.
# They should be created using patch level 1: diff -up ./gdb (or gdb-6.3/gdb).

# Cleanup any leftover testsuite processes as it may stuck mock(1) builds.
Source2:        gdb-orphanripper.c

# Man page for gstack(1).
Source3:        gdb-gstack.man

# libstdc++ pretty printers from GCC SVN HEAD (4.5 experimental).
%define libstdcxxpython libstdc++-v3-python-r155978
Source4:        %{libstdcxxpython}.tar.bz2

# Work around out-of-date dejagnu that does not have KFAIL
Patch1:         gdb-6.3-rh-dummykfail-20041202.patch

# Match the Fedora's version info.
Patch2:         gdb-6.3-rh-testversion-20041202.patch

# Check that libunwind works - new test then fix
Patch3:         gdb-6.3-rh-testlibunwind-20041202.patch

# Use convert_from_func_ptr_addr on the solib breakpoint address;
# simplifies and makes more consistent the logic.
Patch104:       gdb-6.3-ppcdotsolib-20041022.patch

# Better parse 64-bit PPC system call prologues.
Patch105:       gdb-6.3-ppc64syscall-20040622.patch

# Stop a backtrace when a zero PC is encountered.
Patch106:       gdb-6.3-framepczero-20040927.patch

# Include the pc's section when doing a symbol lookup so that the
# correct symbol is found.
Patch111:       gdb-6.3-ppc64displaysymbol-20041124.patch

# Fix upstream `set scheduler-locking step' vs. upstream PPC atomic seqs.
Patch112:       gdb-6.6-scheduler_locking-step-sw-watchpoints2.patch
# Make upstream `set scheduler-locking step' as default.
Patch260:       gdb-6.6-scheduler_locking-step-is-default.patch

# Add a wrapper script to GDB that implements pstack using the
# --readnever option.
Patch118:       gdb-6.3-gstack-20050411.patch

# VSYSCALL and PIE
Patch122:       gdb-6.3-test-pie-20050107.patch
Patch389:       gdb-archer-pie-addons.patch
Patch394:       gdb-archer-pie-addons-keep-disabled.patch

# Get selftest working with sep-debug-info
Patch125:       gdb-6.3-test-self-20050110.patch

# Test support of multiple destructors just like multiple constructors
Patch133:       gdb-6.3-test-dtorfix-20050121.patch

# Fix to support executable moving
Patch136:       gdb-6.3-test-movedir-20050125.patch

# Fix gcore for threads
Patch140:       gdb-6.3-gcore-thread-20050204.patch

# Stop while intentionally stepping and the thread exit is met.
Patch141:       gdb-6.6-step-thread-exit.patch
Patch259:       gdb-6.3-step-thread-exit-20050211-test.patch

# Prevent gdb from being pushed into background
Patch142:       gdb-6.3-terminal-fix-20050214.patch

# Test sibling threads to set threaded watchpoints for x86 and x86-64
Patch145:       gdb-6.3-threaded-watchpoints2-20050225.patch

# Fix printing of inherited members
Patch148:       gdb-6.3-inheritance-20050324.patch

# Do not issue warning message about first page of storage for ia64 gcore
Patch153:       gdb-6.3-ia64-gcore-page0-20050421.patch

# Security errata for untrusted .gdbinit
Patch157:       gdb-6.3-security-errata-20050610.patch

# IA64 sigtramp prev register patch
Patch158:       gdb-6.3-ia64-sigtramp-frame-20050708.patch

# IA64 gcore speed-up patch
Patch160:       gdb-6.3-ia64-gcore-speedup-20050714.patch

# Notify observers that the inferior has been created
Patch161:       gdb-6.3-inferior-notification-20050721.patch

# Fix ia64 info frame bug
Patch162:       gdb-6.3-ia64-info-frame-fix-20050725.patch

# Verify printing of inherited members test
Patch163:       gdb-6.3-inheritancetest-20050726.patch

# Add readnever option
Patch164:       gdb-6.3-readnever-20050907.patch

# Fix ia64 gdb problem with user-specified SIGILL handling
Patch169:       gdb-6.3-ia64-sigill-20051115.patch

# Allow option to continue backtracing past a zero pc value
Patch170:       gdb-6.3-bt-past-zero-20051201.patch

# Use bigger numbers than int.
Patch176:       gdb-6.3-large-core-20051206.patch

# Fix debuginfo addresses resolving for --emit-relocs Linux kernels (BZ 203661).
Patch188:       gdb-6.5-bz203661-emit-relocs.patch

# Security patch: avoid stack overflows in dwarf expression computation.
# CVE-2006-4146
Patch190:       gdb-6.5-dwarf-stack-overflow.patch

# Support TLS symbols (+`errno' suggestion if no pthread is found) (BZ 185337).
Patch194:       gdb-6.5-bz185337-resolve-tls-without-debuginfo-v2.patch

# Fix TLS symbols resolving for objects with separate .debug file (-debuginfo).
Patch195:       gdb-6.5-tls-of-separate-debuginfo.patch

# Fix TLS symbols resolving for shared libraries with a relative pathname.
# The testsuite needs `gdb-6.5-tls-of-separate-debuginfo.patch'.
Patch196:       gdb-6.5-sharedlibrary-path.patch

# Suggest fixing your target architecture for gdbserver(1) (BZ 190810).
# FIXME: It could be autodetected.
Patch199:       gdb-6.5-bz190810-gdbserver-arch-advice.patch

# Fix `gcore' command for 32bit inferiors on 64bit hosts.
Patch201:       gdb-6.5-gcore-i386-on-amd64.patch

# Testcase for deadlocking on last address space byte; for corrupted backtraces.
Patch211:       gdb-6.5-last-address-space-byte-test.patch

# Improved testsuite results by the testsuite provided by the courtesy of BEA.
Patch208:       gdb-6.5-BEA-testsuite.patch

# Fix readline segfault on excessively long hand-typed lines.
Patch209:       gdb-6.5-readline-long-line-crash.patch
Patch213:       gdb-6.5-readline-long-line-crash-test.patch

# Fix bogus 0x0 unwind of the thread's topmost function clone(3) (BZ 216711).
Patch214:       gdb-6.5-bz216711-clone-is-outermost.patch

# Test sideeffects of skipping ppc .so libs trampolines (BZ 218379).
Patch216:       gdb-6.5-bz218379-ppc-solib-trampoline-test.patch

# Fix lockup on trampoline vs. its function lookup; unreproducible (BZ 218379).
Patch217:       gdb-6.5-bz218379-solib-trampoline-lookup-lock-fix.patch

# Find symbols properly at their original (included) file (BZ 109921).
Patch225:       gdb-6.5-bz109921-DW_AT_decl_file-test.patch

# Update PPC unwinding patches to their upstream variants (BZ 140532).
Patch229:       gdb-6.3-bz140532-ppc-unwinding-test.patch

# Testcase for exec() from threaded program (BZ 202689).
Patch231:       gdb-6.3-bz202689-exec-from-pthread-test.patch

# Backported fixups post the source tarball.
Patch232:       gdb-upstream.patch

# Testcase for PPC Power6/DFP instructions disassembly (BZ 230000).
Patch234:       gdb-6.6-bz230000-power6-disassembly-test.patch

# Temporary support for shared libraries >2GB on 64bit hosts. (BZ 231832)
Patch235:       gdb-6.3-bz231832-obstack-2gb.patch

# Fix prelink(8) testcase for non-root $PATH missing `/usr/sbin' (BZ 225783).
Patch240:       gdb-6.6-bz225783-prelink-path.patch

# Fix debugging GDB itself - the compiled in source files paths (BZ 225783).
Patch241:       gdb-6.6-bz225783-gdb-debuginfo-paths.patch

# Allow running `/usr/bin/gcore' with provided but inaccessible tty (BZ 229517).
Patch245:       gdb-6.6-bz229517-gcore-without-terminal.patch

# Notify user of a child forked process being detached (BZ 235197).
Patch247:       gdb-6.6-bz235197-fork-detach-info.patch

# New testcase for gcore of 32bit inferiors on 64bit hosts.
Patch249:       gdb-6.6-gcore32-test.patch

# Avoid too long timeouts on failing cases of "annota1.exp annota3.exp".
Patch254:       gdb-6.6-testsuite-timeouts.patch

# Support for stepping over PPC atomic instruction sequences (BZ 237572).
Patch258:       gdb-6.6-bz237572-ppc-atomic-sequence-test.patch

# Link with libreadline provided by the operating system.
Patch261:       gdb-6.6-readline-system.patch

# Test kernel VDSO decoding while attaching to an i386 process.
Patch263:       gdb-6.3-attach-see-vdso-test.patch

# Do not hang on exit of a thread group leader (BZ 247354).
Patch265:       gdb-6.6-bz247354-leader-exit-fix.patch
Patch266:       gdb-6.6-bz247354-leader-exit-test.patch

# Test leftover zombie process (BZ 243845).
Patch271:       gdb-6.5-bz243845-stale-testing-zombie-test.patch

# New locating of the matching binaries from the pure core file (build-id).
Patch274:       gdb-6.6-buildid-locate.patch
Patch353:       gdb-6.6-buildid-locate-rpm.patch

# Fix displaying of numeric char arrays as strings (BZ 224128).
Patch282:       gdb-6.7-charsign-test.patch

# Test PPC hiding of call-volatile parameter register.
Patch284:       gdb-6.7-ppc-clobbered-registers-O2-test.patch

# Testsuite fixes for more stable/comparable results.
Patch287:       gdb-6.7-testsuite-stable-results.patch

# Test ia64 memory leaks of the code using libunwind.
Patch289:       gdb-6.5-ia64-libunwind-leak-test.patch

# Test hiding unexpected breakpoints on intentional step commands.
Patch290:       gdb-6.5-missed-trap-on-step-test.patch

# Support DW_TAG_interface_type the same way as DW_TAG_class_type (BZ 426600).
Patch293:       gdb-6.7-bz426600-DW_TAG_interface_type-fix.patch
Patch294:       gdb-6.7-bz426600-DW_TAG_interface_type-test.patch

# Test gcore memory and time requirements for large inferiors.
Patch296:       gdb-6.5-gcore-buffer-limit-test.patch

# Test debugging statically linked threaded inferiors (BZ 239652).
#  - It requires recent glibc to work in this case properly.
Patch298:       gdb-6.6-threads-static-test.patch

# Fix #include <asm/ptrace.h> on kernel-headers-2.6.25-0.40.rc1.git2.fc9.x86_64.
Patch304:       gdb-6.7-kernel-headers-compat.patch

# Test GCORE for shmid 0 shared memory mappings.
Patch309:       gdb-6.3-mapping-zero-inode-test.patch

# Test a crash on `focus cmd', `focus prev' commands.
Patch311:       gdb-6.3-focus-cmd-prev-test.patch

# Test various forms of threads tracking across exec() (BZ 442765).
Patch315:       gdb-6.8-bz442765-threaded-exec-test.patch

# Silence memcpy check which returns false positive (sparc64)
Patch317:       gdb-6.8-sparc64-silence-memcpy-check.patch

# Fix memory trashing on binaries from GCC Ada (workaround GCC PR 35998).
Patch318:       gdb-6.8-gcc35998-ada-memory-trash.patch

# Test a crash on libraries missing the .text section.
Patch320:       gdb-6.5-section-num-fixup-test.patch

# Refuse creating watchpoints of an address value, suggested by Martin Stransky.
Patch322:       gdb-6.8-constant-watchpoints.patch

# Fix compatibility with recent glibc headers.
Patch324:       gdb-6.8-glibc-headers-compat.patch

# Create a single binary `gdb' autodetecting --tui by its argv[0].
Patch326:       gdb-6.8-tui-singlebinary.patch

# Fix PRPSINFO in the core files dumped by gcore (BZ 254229).
Patch329:       gdb-6.8-bz254229-gcore-prpsinfo.patch

# Fix register assignments with no GDB stack frames (BZ 436037).
Patch330:       gdb-6.8-bz436037-reg-no-longer-active.patch

# Make the GDB quit processing non-abortable to cleanup everything properly.
Patch331:       gdb-6.8-quit-never-aborts.patch

# Support DW_TAG_constant for Fortran in recent Fedora/RH GCCs.
Patch332:       gdb-6.8-fortran-tag-constant.patch

# Fix attaching to stopped processes and/or pending signals.
Patch337:       gdb-6.8-attach-signalled-detach-stopped.patch

# Test the watchpoints conditionals works.
Patch343:       gdb-6.8-watchpoint-conditionals-test.patch

# Fix resolving of variables at locations lists in prelinked libs (BZ 466901).
Patch348:       gdb-6.8-bz466901-backtrace-full-prelinked.patch

# The merged branch `archer' of: http://sourceware.org/gdb/wiki/ProjectArcher
Patch349:       gdb-archer.patch
Patch420:       gdb-archer-ada.patch

# Fix parsing elf64-i386 files for kdump PAE vmcore dumps (BZ 457187).
# - Turn on 64-bit BFD support, globally enable AC_SYS_LARGEFILE.
Patch360:       gdb-6.8-bz457187-largefile-test.patch

# New test for step-resume breakpoint placed in multiple threads at once.
Patch381:       gdb-simultaneous-step-resume-breakpoint-test.patch

# Fix GNU/Linux core open: Can't read pathname for load map: Input/output error.
Patch382:       gdb-core-open-vdso-warning.patch

# Fix syscall restarts for amd64->i386 biarch.
Patch391:       gdb-x86_64-i386-syscall-restart.patch

# Fix stepping with OMP parallel Fortran sections (BZ 533176).
Patch392:       gdb-bz533176-fortran-omp-step.patch

# Fix regression by python on ia64 due to stale current frame.
Patch397:       gdb-follow-child-stale-parent.patch

# Workaround ccache making lineno non-zero for command-line definitions.
Patch403:       gdb-ccache-workaround.patch

# Implement `info common' for Fortran.
Patch404:       gdb-fortran-common-reduce.patch
Patch405:       gdb-fortran-common.patch

# Fix Fortran logical-kind=8 (BZ 465310).
Patch406:       gdb-fortran-logical8.patch

# Testcase for "Do not make up line information" fix by Daniel Jacobowitz.
Patch407:       gdb-lineno-makeup-test.patch

# Test power7 ppc disassembly.
Patch408:       gdb-ppc-power7-test.patch

# Revert: Add -Wunused-function to compile flags.
Patch412:       gdb-unused-revert.patch

# Fix i386+x86_64 rwatch+awatch before run, regression against 6.8 (BZ 541866).
Patch417:       gdb-bz541866-rwatch-before-run.patch

# Remove false gdb_assert on $sp underflow.
Patch422:       gdb-infcall-sp-underflow.patch

# Fix double-free on std::terminate handler (Tom Tromey, BZ 562975).
Patch429:       gdb-bz562975-std-terminate-double-free.patch

# PIE: Fix back re-reun.
Patch430:       gdb-pie-rerun.patch

# Do not consider memory error on reading _r_debug->r_map as fatal (BZ 576742).
Patch432:       gdb-solib-memory-error-nonfatal.patch

# testsuite: Fix unstable results of gdb.base/prelink.exp.
Patch433:       gdb-6.7-testsuite-stable-results-prelink.patch 

# [patch 1/6] PIE: Attach binary even after re-prelinked underneath
# [patch 2/6] PIE: Attach binary even after ld.so re-prelinked underneath
# [patch 3/6] PIE: Fix occasional error attaching i686 binary
Patch434:       gdb-pie-1of6-reprelinked-bin.patch
Patch435:       gdb-pie-2of6-reprelinked-ld.patch
Patch436:       gdb-pie-3of6-relocate-once.patch

# [expr-cumulative] using-directive: Fix memory leak (Sami Wagiaalla).
Patch437:       gdb-using-directive-leak.patch

# Fix dangling displays in separate debuginfo (BZ 574483).
Patch438:       gdb-bz574483-display-sepdebug.patch

# Support AVX registers (BZ 578250).
Patch439:       gdb-bz578250-avx-01of10.patch
Patch440:       gdb-bz578250-avx-02of10.patch
Patch441:       gdb-bz578250-avx-03of10.patch
Patch442:       gdb-bz578250-avx-04of10.patch
Patch443:       gdb-bz578250-avx-05of10.patch
Patch444:       gdb-bz578250-avx-06of10.patch
Patch445:       gdb-bz578250-avx-07of10.patch
Patch446:       gdb-bz578250-avx-08of10.patch
Patch447:       gdb-bz578250-avx-09of10.patch
Patch448:       gdb-bz578250-avx-10of10.patch
Patch449:       gdb-bz578250-avx-10of10-ppc.patch

# Fix crash on C++ types in some debug info files (BZ 575292, Keith Seitz).
# Temporarily workaround the crash of BZ 575292 as there was now BZ 585445.
# Re-enable the BZ 575292 and BZ 585445 C++ fix using an updated patch.
Patch451:       gdb-bz575292-delayed-physname.patch
Patch455:       gdb-bz575292-void-workaround.patch

# Pretty printers not well documented (BZ 570635, Tom Tromey, Jan Kratochvil).
Patch452:       gdb-bz570635-prettyprint-doc1.patch
Patch453:       gdb-bz570635-prettyprint-doc2.patch

# Fix crash when using GNU IFUNC call from breakpoint condition.
Patch454:       gdb-bz539590-gnu-ifunc-fix-cond.patch

# Fail gracefully if the _Unwind_DebugHook arg. is optimized out (Tom Tromey).
# Make _Unwind_DebugHook independent from step-resume breakpoint (Tom Tromey).
Patch456:       gdb-unwind-debughook-safe-fail.patch
Patch457:       gdb-unwind-debughook-step-independent.patch

# testsuite: Fix gdb.base/vla-overflow.exp FAILing on s390x (BZ 590635).
Patch458:       gdb-archer-vla-test-oom.patch

# Workaround non-stop moribund locations exploited by kernel utrace (BZ 590623).
Patch459:       gdb-moribund-utrace-workaround.patch

# Fix crash on VLA bound referencing an optimized-out variable (BZ 591879).
Patch460:       gdb-archer-vla-ref-optimizedout.patch

# Remove core file when starting a process (BZ 594560).
Patch461:       gdb-bz594560-core-vs-process.patch

# Import fix of TUI layout internal error (BZ 595475).
Patch462:       gdb-bz595475-tui-layout.patch

# Fix and support DW_OP_*piece (Tom Tromey, BZ 589467).
Patch463:       gdb-bz589467-pieces01of4.patch
Patch464:       gdb-bz589467-pieces02of4.patch
Patch465:       gdb-bz589467-pieces03of4.patch
Patch466:       gdb-bz589467-pieces1of4.patch
Patch467:       gdb-bz589467-pieces2of4.patch
Patch468:       gdb-bz589467-pieces3of4.patch
Patch469:       gdb-bz589467-pieces4of4.patch
Patch471:       gdb-bz589467-pieces-vla-compat.patch

# Fix follow-exec for C++ programs (bugreported by Martin Stransky).
Patch470:       gdb-archer-next-over-throw-cxx-exec.patch

# Fix ADL anonymous type crash (BZ 600746, Sami Wagiaalla).
Patch472:       gdb-bz600746-koenig-crash.patch

# Backport DWARF-4 support (BZ 601887, Tom Tromey).
Patch473:       gdb-bz601887-dwarf4-1of2.patch
Patch474:       gdb-bz601887-dwarf4-2of2.patch
Patch475:       gdb-bz601887-dwarf4-rh-test.patch

# Fix obstack corruptions on C++ (BZ 606185, Chris Moller, Jan Kratochvil).
Patch476:       gdb-bz606185-obstack-1of5.patch
Patch477:       gdb-bz606185-obstack-2of5.patch
Patch478:       gdb-bz606185-obstack-3of5.patch
Patch479:       gdb-bz606185-obstack-4of5.patch
Patch480:       gdb-bz606185-obstack-5of5.patch

# Improve support for typedefs in classes (BZ 602314).
Patch481:       gdb-bz602314-ptype-class-typedef-1of3.patch
Patch482:       gdb-bz602314-ptype-class-typedef-2of3.patch
Patch483:       gdb-bz602314-ptype-class-typedef-3of3.patch

# Fix `set print object on' for some non-dynamic classes (BZ 606660).
Patch484:       gdb-bz606660-print-object-nonvirtual.patch

# Print 2D C++ vectors as matrices (BZ 562763, sourceware10659, Chris Moller).
Patch485:       gdb-bz562763-pretty-print-2d-vectors-prereq.patch
Patch486:       gdb-bz562763-pretty-print-2d-vectors.patch
Patch487:       gdb-bz562763-pretty-print-2d-vectors-libstdcxx.patch

# Fix prelinked executables with sepdebug and copy relocations (BZ 614659).
Patch489:       gdb-bz614659-prelink-dynbss.patch

# [delayed-symfile] Fix a backtrace regression on CFIs without DIE (BZ 614604).
Patch490:       gdb-bz614604-bt-cfi-without-die.patch

# Fix crash in gdbpy_is_string (BZ 611569, Tom Tromey).
Patch492:       gdb-bz611569-gdbpy_is_string.patch

# Fix long delay printing an overflown stack backtrace (BZ 620012, Tom Tromey).
Patch494:       gdb-bz620012-slow-long-bt.patch

# Fix GDB regression for starting on r/o filesystem (BZ 602644).
Patch495:       gdb-bz602644-ro-filesystem.patch

# Fix readline 5.1 warnings
Patch1000:      readline-5.1-random.patch
# Upstream patch to fix gcc -Werror
Patch1001:      gdb-7.1-werror.patch
Patch1002:      gdb-6.6-buildid-locate-rpm-suse.patch
# Fix build on hppa
Patch1003:      gdb-hppa.patch
# Fix setting of VSX registers, bnc#626970
Patch1004:      gdb-7.1-bnc626970.patch
# Fix gcore with GNU_RELRO sections, bnc#596646
Patch1005:      gdb-7.2-bnc596646.patch
# Fix "Failed to read a valid object file image from memory."
Patch1006:      gdb-bnc640875.patch

BuildRequires:  bison flex gettext glibc-devel ncurses-devel texinfo zlib-devel
%if %{suse_version} < 1020
BuildRequires:  expat
%else
BuildRequires:  libexpat-devel
%endif
BuildRequires:  readline-devel
BuildRequires:  zlib-devel
%if 0%{!?_without_python:1}
%if 0%{suse_version} > 1000
Recommends:     python-base
%endif
BuildRequires:  python-devel
%endif	# 0%{!?_without_python:1}

%if 0%{?_with_testsuite:1}

# Ensure the devel libraries are installed for both multilib arches.
%define bits_local %{?_isa}
%define bits_other %{?_isa}
%if 0%{!?el5:1}
%ifarch s390x
%define bits_other (%{__isa_name}-32)
%else #!s390x
%ifarch ppc
%define bits_other (%{__isa_name}-64)
%else #!ppc
%ifarch sparc64 ppc64 s390x x86_64
%define bits_other (%{__isa_name}-32)
%endif #sparc64 ppc64 s390x x86_64
%endif #!ppc
%endif #!s390x
%endif #!el5

BuildRequires:  dejagnu sharutils
# gcc-objc++ is not covered by the GDB testsuite.
BuildRequires:  gcc gcc-c++ gcc-gfortran gcc-java gcc-objc
# Copied from gcc-4.1.2-32.
%ifarch %{ix86} x86_64 ia64 ppc alpha
BuildRequires:  gcc-ada
%endif
BuildRequires:  glibc-devel-32bit
%if 0%{suse_version} > 1120
BuildRequires:  gcc-c++-32bit
%endif

%endif # 0%{?_with_testsuite:1}

%ifarch ia64
BuildRequires:  libunwind-devel
Requires:       libunwind
%endif

PreReq:         %install_info_prereq

%description
You can use GDB to debug programs written in C, C++, Ada, and Modula-2.
GNU Fortran 77 support is also partially included.



Authors:
--------
    Doug Evans <dje@cygnus.com>
    Fred Fish <fnf@cygnus.com>
    Ian Lance Taylor <ian@cygnus.com>
    J.T. Conklin <jtc@cygnus.com>
    Jason Molenda <crash@cygnus.com>
    Jeffrey A. Law <law@cygnus.com>
    Jim Kingdon <kingdon@cygnus.com>
    Kung Hsu <kung@cygnus.com>
    Michael Meissner <meissner@cygnus.com>
    Per Bothner <bothner@cygnus.com>
    Peter Schauer <pes@regent.e-technik.tu-muenchen.de>
    Rob Savoye <rob@cygnus.com>
    Stan Shebs <shebs@cygnus.com>
    Steve Chamberlain <sac@cygnus.com>
    Stu Grossman <grossman@cygnus.com>

%prep

# This allows the tarball name to be different from our
# version-release name.

%setup -q -n %{gdb_src}

# libstdc++ pretty printers.
tar xjf %{SOURCE4}

# Files have `# <number> <file>' statements breaking VPATH / find-debuginfo.sh .
rm -f gdb/ada-exp.c gdb/ada-lex.c gdb/c-exp.c gdb/cp-name-parser.c gdb/f-exp.c
rm -f gdb/jv-exp.c gdb/m2-exp.c gdb/objc-exp.c gdb/p-exp.c

# Apply patches defined above.

# Match the Fedora's version info.
%patch2 -p1

%if 0%{!?_with_upstream:1}

%patch232 -p1
%patch349 -p1
%patch420 -p1
%patch1 -p1
%patch3 -p1

%patch104 -p1
%patch105 -p1
%patch106 -p1
%patch111 -p1
%patch112 -p1
%patch118 -p1
%patch122 -p1
%patch125 -p1
%patch133 -p1
%patch136 -p1
%patch140 -p1
%patch141 -p1
%patch259 -p1
%patch142 -p1
%patch145 -p1
%patch148 -p1
%patch153 -p1
%patch157 -p1
%patch158 -p1
%patch160 -p1
%patch161 -p1
%patch162 -p1
%patch163 -p1
%patch164 -p1
%patch169 -p1
%patch170 -p1
%patch176 -p1
%patch188 -p1
%patch190 -p1
%patch194 -p1
%patch195 -p1
%patch196 -p1
%patch199 -p1
%patch201 -p1
%patch208 -p1
%patch209 -p1
%patch211 -p1
%patch213 -p1
%patch214 -p1
%patch216 -p1
%patch217 -p1
%patch225 -p1
%patch229 -p1
%patch231 -p1
%patch234 -p1
%patch235 -p1
%patch240 -p1
%patch241 -p1
%patch245 -p1
%patch247 -p1
%patch249 -p1
%patch254 -p1
%patch258 -p1
%patch260 -p1
%patch261 -p1
%patch263 -p1
%patch265 -p1
%patch266 -p1
%patch271 -p1
%patch274 -p1
%patch353 -p1
%patch282 -p1
%patch284 -p1
%patch287 -p1
%patch289 -p1
%patch290 -p1
%patch293 -p1
%patch294 -p1
%patch296 -p1
%patch298 -p1
%patch304 -p1
%patch309 -p1
%patch311 -p1
%patch315 -p1
%patch317 -p1
%patch318 -p1
%patch320 -p1
%patch322 -p1
%patch324 -p1
%patch326 -p1
%patch329 -p1
%patch330 -p1
%patch331 -p1
%patch332 -p1
%patch337 -p1
%patch343 -p1
%patch348 -p1
%patch360 -p1
%patch381 -p1
%patch382 -p1
%patch391 -p1
%patch392 -p1
%patch397 -p1
%patch403 -p1
%patch404 -p1
%patch405 -p1
%patch389 -p1
%patch394 -p1
%patch406 -p1
%patch407 -p1
%patch408 -p1
%patch412 -p1
%patch417 -p1
%patch422 -p1
%patch429 -p1
%patch430 -p1
%patch432 -p1
%patch433 -p1
%patch434 -p1
%patch435 -p1
%patch436 -p1
%patch437 -p1
%patch438 -p1
%patch439 -p1
%patch440 -p1
%patch441 -p1
%patch442 -p1
%patch443 -p1
%patch444 -p1
%patch445 -p1
%patch446 -p1
%patch447 -p1
%patch448 -p1
%patch449 -p1
%patch451 -p1
%patch452 -p1
%patch453 -p1
%patch454 -p1
%patch455 -p1
%patch456 -p1
%patch457 -p1
%patch458 -p1
%patch459 -p1
%patch460 -p1
%patch461 -p1
%patch462 -p1
%patch463 -p1
%patch464 -p1
%patch465 -p1
%patch466 -p1
%patch467 -p1
%patch468 -p1
%patch469 -p1
%patch471 -p1
%patch470 -p1
%patch472 -p1
%patch473 -p1
%patch474 -p1
%patch475 -p1
%patch476 -p1
%patch477 -p1
%patch478 -p1
%patch479 -p1
%patch480 -p1
%patch481 -p1
%patch482 -p1
%patch483 -p1
%patch484 -p1
%patch485 -p1
%patch486 -p1
%patch487 -p1
%patch489 -p1
%patch490 -p1
%patch492 -p1
%patch494 -p1
%patch495 -p1

%patch1000
%patch1001 -p0
%patch1002 -p1
%patch1003
%patch1004 -p1
%patch1005 -p1
%patch1006

find -name "*.orig" | xargs rm -f
! find -name "*.rej" # Should not happen.

%endif # 0%{!?_with_upstream:1}

# Change the version that gets printed at GDB startup, so it is SUSE 
# specific.
# Fedora (%{version}-%{release})
# Red Hat Enterprise Linux (%{version}-%{release})
cat > gdb/version.in << _FOO
SUSE (%{version}-%{release})
_FOO

# Remove the info and other generated files added by the FSF release
# process.
rm -f libdecnumber/gstdint.h
rm -f bfd/doc/*.info
rm -f bfd/doc/*.info-*
rm -f gdb/doc/*.info
rm -f gdb/doc/*.info-*

%build

# Identify the build directory with the version of gdb as well as the
# architecture, to allow for mutliple versions to be installed and
# built.
# Initially we're in the %{gdb_src} directory.

rm -fr %{gdb_build}
mkdir %{gdb_build}
cd %{gdb_build}

# g77 executable is no longer present in Fedora gcc-4.x+.
g77="`which gfortran 2>/dev/null || true`"
test -z "$g77" || ln -s "$g77" ./g77

export CFLAGS="$RPM_OPT_FLAGS"

%if 0%{?_with_debug:1}
# --enable-werror could conflict with `-Wall -O0' but this is no longer true
# for recent GCCs.
CFLAGS="$CFLAGS -O0 -ggdb2"
%endif

../configure							\
	--prefix=%{_prefix}					\
	--libdir=%{_libdir}					\
	--sysconfdir=%{_sysconfdir}				\
	--mandir=%{_mandir}					\
	--infodir=%{_infodir}					\
	--with-gdb-datadir=%{_datadir}/gdb			\
	--with-pythondir=%{_datadir}/gdb/python			\
	--enable-gdb-build-warnings=,-Wno-unused		\
%ifnarch %{ix86} alpha ia64 ppc s390 s390x x86_64 ppc64 sparcv9 sparc64
	--disable-werror					\
%else
%if 0%{?_with_upstream:1}
	--disable-werror					\
%else
	--enable-werror						\
%endif
%endif
	--with-separate-debug-dir=/usr/lib/debug		\
	--disable-sim						\
	--disable-rpath						\
	--with-system-readline					\
	--with-expat						\
$(: ppc64 host build crashes on ppc variant of libexpat.so )	\
	--without-libexpat-prefix				\
	--enable-tui						\
%if 0%{!?_without_python:1}
	--with-python						\
%else
	--without-python					\
%endif
	--without-rpm						\
%ifarch ia64
	--with-libunwind					\
%else
	--without-libunwind					\
%endif
	--enable-64-bit-bfd					\
%if 0%{?_with_debug:1}
	--enable-static --disable-shared --enable-debug		\
%endif
%ifarch sparcv9
	sparc-%{_vendor}-%{_target_os}%{?_gnu}
%else
	%{_target_platform}
%endif

make %{?_smp_mflags}
make %{?_smp_mflags} info

grep '#define HAVE_ZLIB_H 1' gdb/config.h

# Copy the <sourcetree>/gdb/NEWS file to the directory above it.
cp $RPM_BUILD_DIR/%{gdb_src}/gdb/NEWS $RPM_BUILD_DIR/%{gdb_src}

%check
# Initially we're in the %{gdb_src} directory.
cd %{gdb_build}

%if 0%{!?_with_testsuite:1}
echo ====================TESTSUITE DISABLED=========================
%else
echo ====================TESTING=========================
cd gdb
gcc -o ./orphanripper %{SOURCE2} -Wall -lutil -ggdb2
# Need to use a single --ignore option, second use overrides first.
# No `%{?_smp_mflags}' here as it may race.
# WARNING: can't generate a core file - core tests suppressed - check ulimit
# "readline-overflow.exp" - Testcase is broken, functionality is OK.
(
  # ULIMIT required for `gdb.base/auxv.exp'.
  ulimit -H -c
  ulimit -c unlimited || :

  # Setup $CHECK as `check//unix/' or `check//unix/-m64' for explicit bitsize.
  # Never use two different bitsizes as it fails on ppc64.
  echo 'int main (void) { return 0; }' >biarch.c
  CHECK=""
  for BI in -m64 -m32 -m31 ""
  do
    # Do not use size-less options if any of the sizes works.
    # On ia64 there is no -m64 flag while we must not leave a bare `check' here
    # as it would switch over some testing scripts to the backward compatibility
    # mode: when `make check' was executed from inside the testsuite/ directory.
    if [ -z "$BI" -a -n "$CHECK" ];then
      continue
    fi
    # Do not use $RPM_OPT_FLAGS as the other non-size options will not be used
    # in the real run of the testsuite.
    if ! gcc $BI -o biarch biarch.c
    then
      continue
    fi
    CHECK="$CHECK check//unix/$BI"
  done
  # Do not try -m64 inferiors for -m32 GDB as it cannot handle inferiors larger
  # than itself.
  # s390 -m31 still uses the standard ELF32 binary format.
  gcc $RPM_OPT_FLAGS -o biarch biarch.c
  RPM_SIZE="$(file ./biarch|sed -n 's/^.*: ELF \(32\|64\)-bit .*$/\1/p')"
  if [ "$RPM_SIZE" != "64" ]
  then
    CHECK="$(echo " $CHECK "|sed 's# check//unix/-m64 # #')"
  fi

  # Disable some problematic testcases.
  # RUNTESTFLAGS='--ignore ...' is not used below as it gets separated by the
  # `check//...' target spawn and too much escaping there would be dense.
  for test in				\
    gdb.base/readline-overflow.exp	\
    gdb.base/bigcore.exp		\
  ; do
    mv -f ../../gdb/testsuite/$test ../gdb/testsuite/$test-DISABLED || :
  done

%if 0%{!?_with_upstream:1}
  # Run all the scheduled testsuite runs also in the PIE mode.
  # Upstream GDB would lock up the testsuite run for too long on its failures.
  CHECK="$(echo $CHECK|sed 's#check//unix/[^ ]*#& &/-fPIE/-pie#g')"
%endif # 0%{!?_with_upstream:1}

  ./orphanripper make %{?_smp_mflags} -k $CHECK \
$(: Serialize the output to keep the order for regression checks. ) \
%if 0%{?el5:1}
    RUNTESTFLAGS="--tool gdb" \
%endif
    || :
)
for t in sum log
do
  for file in testsuite*/gdb.$t
  do
    suffix="${file#testsuite.unix.}"
    suffix="${suffix%/gdb.$t}"
    ln $file gdb-%{_target_platform}$suffix.$t || :
  done
done
# `tar | bzip2 | uuencode' may have some piping problems in Brew.
tar cjf gdb-%{_target_platform}.tar.bz2 gdb-%{_target_platform}*.{sum,log}
uuencode gdb-%{_target_platform}.tar.bz2 gdb-%{_target_platform}.tar.bz2
cd ../..
echo ====================TESTING END=====================
%endif

%install
# Initially we're in the %{gdb_src} directory.
cd %{gdb_build}
rm -rf $RPM_BUILD_ROOT

make %{?_smp_mflags} install DESTDIR=$RPM_BUILD_ROOT

# install the gcore script in /usr/bin
cp $RPM_BUILD_DIR/%{gdb_src}/gdb/gdb_gcore.sh $RPM_BUILD_ROOT%{_bindir}/gcore
chmod 755 $RPM_BUILD_ROOT%{_bindir}/gcore

# Remove the gdb/gdbtui binaries duplicity.
test -x $RPM_BUILD_ROOT%{_prefix}/bin/gdbtui
ln -sf gdb $RPM_BUILD_ROOT%{_prefix}/bin/gdbtui
cmp $RPM_BUILD_ROOT%{_mandir}/*/gdb.1 $RPM_BUILD_ROOT%{_mandir}/*/gdbtui.1
ln -sf gdb.1 $RPM_BUILD_ROOT%{_mandir}/*/gdbtui.1

%if 0%{!?_without_python:1}
# Temporarily now:
for LIB in lib lib64;do
  LIBPATH="$RPM_BUILD_ROOT%{_datadir}/gdb/auto-load%{_prefix}/$LIB"
  mkdir -p $LIBPATH
  # basename is being run only for the native (non-biarch) file.
  sed -e 's,@pythondir@,%{_datadir}/gdb/python,'		\
      -e 's,@toolexeclibdir@,%{_prefix}/'"$LIB,"		\
      < $RPM_BUILD_DIR/%{gdb_src}/%{libstdcxxpython}/hook.in	\
      > $LIBPATH/$(basename %{_prefix}/%{_lib}/libstdc++.so.6.*)-gdb.py
done
test ! -e $RPM_BUILD_ROOT%{_datadir}/gdb/python/libstdcxx
cp -a $RPM_BUILD_DIR/%{gdb_src}/%{libstdcxxpython}/libstdcxx	\
      $RPM_BUILD_ROOT%{_datadir}/gdb/python/libstdcxx
%endif # 0%{!?_without_python:1}

# Remove the files that are part of a gdb build but that are owned and
# provided by other packages.
# These are part of binutils

rm -rf $RPM_BUILD_ROOT%{_datadir}/locale/
rm -f $RPM_BUILD_ROOT%{_infodir}/bfd*
rm -f $RPM_BUILD_ROOT%{_infodir}/standard*
rm -f $RPM_BUILD_ROOT%{_infodir}/mmalloc*
rm -f $RPM_BUILD_ROOT%{_infodir}/configure*
rm -rf $RPM_BUILD_ROOT%{_includedir}
rm -rf $RPM_BUILD_ROOT/%{_libdir}/lib{bfd*,opcodes*,iberty*,mmalloc*}

# Delete this too because the dir file will be updated at rpm install time.
# We don't want a gdb specific one overwriting the system wide one.

rm -f $RPM_BUILD_ROOT%{_infodir}/dir

%if 0%{!?_with_upstream:1}
# pstack obsoletion

cp -p %{SOURCE3} $RPM_BUILD_ROOT%{_mandir}/man1/gstack.1
%endif	# 0%{!?_with_upstream:1}

%clean
rm -rf $RPM_BUILD_ROOT

%post
# This step is part of the installation of the RPM. Not to be confused
# with the 'make install ' of the build (rpmbuild) process.

# For --excludedocs:
if [ -e %{_infodir}/gdb.info.gz ]
then
  %install_info --info-dir=%{_infodir} %{_infodir}/annotate.info.gz
  %install_info --info-dir=%{_infodir} %{_infodir}/gdb.info.gz
  %install_info --info-dir=%{_infodir} %{_infodir}/gdbint.info.gz
  %install_info --info-dir=%{_infodir} %{_infodir}/stabs.info.gz
fi

%preun
if [ $1 = 0 ]
then
  # For --excludedocs:
  if [ -e %{_infodir}/gdb.info.gz ]
  then
    %install_info_delete --delete --info-dir=%{_infodir} %{_infodir}/annotate.info.gz
    %install_info_delete --delete --info-dir=%{_infodir} %{_infodir}/gdb.info.gz
    %install_info_delete --delete --info-dir=%{_infodir} %{_infodir}/gdbint.info.gz
    %install_info_delete --delete --info-dir=%{_infodir} %{_infodir}/stabs.info.gz
  fi
fi

%files
%defattr(-,root,root)
%doc COPYING3 COPYING COPYING.LIB README NEWS
%{_bindir}/gcore
%{_bindir}/gdb
%{_bindir}/gdbtui
%{_mandir}/*/gdb.1*
%{_mandir}/*/gdbtui.1*
%if 0%{!?_with_upstream:1}
%{_bindir}/gstack
%{_mandir}/*/gstack.1*
%endif	# 0%{!?_with_upstream:1}
%{_datadir}/gdb
%{_infodir}/annotate.info*
%{_infodir}/gdb.info*
%{_infodir}/gdbint.info*
%{_infodir}/stabs.info*
# In SLE10 gdbserver is not in a separate package
%if %{suse_version} <= 1010
%{_bindir}/gdbserver
%{_mandir}/*/gdbserver.1*
%endif

# don't include the files in include, they are part of binutils

%changelog
* Tue Nov 16 2010 rguenther@novell.com
- Work around PT_LOAD alignment issues.  [bnc#640875]
* Fri Sep 10 2010 rguenther@novell.com
- Make autobuild scripts happy.
* Wed Sep  8 2010 rguenther@novell.com
- Update to GDB 7.1, update 33 from Fedora 13.
  * Many bugfixes and new features.
- Backport fix for gcore not handling GNU_RELRO sections.  [bnc#596646]
- Backport fix for setting of VSX registers.  [bnc#626970]
- Inherit fixes from SLE11 SP1.  [bnc#488132] [bnc#498749] [fate#304116]
* Wed Jul  8 2009 matz@suse.de
- Apply fix for backtraces without unwind info again.  [#390722]
- Disable gdb-6.5-bz218379-ppc-solib-trampoline-fix.patch, it's not
  necessary anymore and breaks the above.
* Tue May 19 2009 rguenther@suse.de
- Merge gdbserver package back to gdb package.
* Mon May 18 2009 rguenther@suse.de
- Add patch to fix handling of string DW_AT_const_values.  [bnc#329420]
- Verified
  * Fix printing of 'inf'.  [bnc#466266]
  * Stepping through templates.  [bnc#414230]
  * gcore script.  [fate#303462]
* Thu May 14 2009 rguenther@suse.de
- Change reported version to mention SUSE instead of Fedora.
- Fix handling of bogus global namespace DIEs from GCC 4.1.  [bnc#329420]
- Fix Power7 DFP detection.  [bnc#492331]
* Thu May  7 2009 rguenther@suse.de
- Fix build for SLE10.  [fate#305977]
- Adjust missing debug packages suggested install command.
* Wed Apr 29 2009 rguenther@suse.de
- Adjust package name and release to not contain macros.
* Mon Apr 27 2009 rguenther@suse.de
- Disable rpm support for locating debug info packages.
* Mon Apr 27 2009 rguenther@suse.de
- Switch to Fedora 11 source RPM.
  * includes partially merge from Archer.  [bnc#329420, bnc#497141,
    bnc#492782]
* Wed Jan 16 2008 schwab@suse.de
- Improve end check on rs6000 prologue analyzer [#353456].
* Tue Jan  8 2008 schwab@suse.de
- Fix crash [#349271].
* Tue Jan  8 2008 schwab@suse.de
- Fix typo [#293372].
* Wed Dec  5 2007 schwab@suse.de
- Fix crashes in TUI [#341651,#344128].
* Wed Nov 28 2007 schwab@suse.de
- Handle symbol overlap [#343738].
* Thu Nov 15 2007 schwab@suse.de
- Add fallback for secure-plt stubs [#341176].
* Wed Nov 14 2007 schwab@suse.de
- Use DW_CC_program to identify Fortran main program [#339349].
* Mon Oct 22 2007 schwab@suse.de
- Fix disassembling dfp insns [#335344].
* Wed Sep 26 2007 schwab@suse.de
- Add init-reg hook [#264255].
* Wed Sep 26 2007 schwab@suse.de
- Disassemble any insn [#310473].
* Tue Jul 24 2007 schwab@suse.de
- Fix handling of function descriptors [#249974].
* Mon Jul 23 2007 schwab@suse.de
- Fix signedness mismatch [#293372].
* Fri Apr 13 2007 schwab@suse.de
- Avoid crash on object with no text section [#176306].
* Wed Apr 11 2007 schwab@suse.de
- Handle non-threaded processes in gstack [#262694].
* Sun Apr  1 2007 schwab@suse.de
- Properly decode CR register number.
* Thu Mar 29 2007 schwab@suse.de
- Update ppc long double patch [#180103].
* Tue Mar 20 2007 schwab@suse.de
- Update single stepping patch again [#154486].
* Fri Mar 16 2007 schwab@suse.de
- Update single stepping patch [#154486].
* Thu Mar 15 2007 schwab@suse.de
- Fix altivec vector return location [#250004].
* Mon Mar 12 2007 schwab@suse.de
- Update ppc DWARF patch to also handle broken debug info from old
  compilers.
* Thu Mar  8 2007 schwab@suse.de
- Deal with stepping over sequence of atomic insns [#154486].
* Tue Mar  6 2007 schwab@suse.de
- Better handling of ppc64 function descriptor symbols.
* Mon Mar  5 2007 schwab@suse.de
- Remove obsolete patch.
- Fix show endian.
* Thu Jan 11 2007 schwab@suse.de
- Fix unchecked use of PC_REGNUM.
* Wed Dec 20 2006 schwab@suse.de
- Update to gdb 6.6.
  * New targets
  Xtensa				xtensa-elf
  Cell Broadband Engine SPU	spu-elf
  * GDB can now be configured as a cross-debugger targeting native Windows
  (mingw32) or Cygwin.  It can communicate with a remote debugging stub
  running on a Windows system over TCP/IP to debug Windows programs.
  * The GDB remote stub, gdbserver, has been updated to support Windows and
  Cygwin debugging.  Both single-threaded and multi-threaded programs are
  supported.
  * The "set trust-readonly-sections" command works again.  This command was
  broken in GDB 6.3, 6.4, and 6.5.
  * Support for GNU/Linux Thread Local Storage (TLS, per-thread variables) no
  longer requires symbolic debug information (e.g. DWARF-2).
  * New commands
  set substitute-path
  unset substitute-path
  show substitute-path
    Manage a list of substitution rules that GDB uses to rewrite the name
    of the directories where the sources are located. This can be useful
    for instance when the sources were moved to a different location
    between compilation and debugging.
  set trace-commands
  show trace-commands
    Print each CLI command as it is executed.  Each command is prefixed with
    a number of `+' symbols representing the nesting depth.
    The source command now has a `-v' option to enable the same feature.
  * REMOVED features
  The ARM Demon monitor support (RDP protocol, "target rdp").
  Kernel Object Display, an embedded debugging feature which only worked with
  an obsolete version of Cisco IOS.
  The 'set download-write-size' and 'show download-write-size' commands.
  * New remote packets
  qSupported:
    Tell a stub about GDB client features, and request remote target features.
    The first feature implemented is PacketSize, which allows the target to
    specify the size of packets it can handle - to minimize the number of
    packets required and improve performance when connected to a remote
    target.
  qXfer:auxv:read:
    Fetch an OS auxilliary vector from the remote stub.  This packet is a
    more efficient replacement for qPart:auxv:read.
  * Removed remote packets
  qPart:auxv:read:
    This packet has been replaced by qXfer:auxv:read.  Only GDB 6.4 and 6.5
    used it, and only gdbserver implemented it.
* Fri Oct 27 2006 schwab@suse.de
- Rename detach-fork to detach fork.
* Tue Oct 24 2006 schwab@suse.de
- Better fix for function descriptor handling on ppc64.
* Fri Aug 25 2006 schwab@suse.de
- Minimal support for .gnu.hash.
* Thu Aug 24 2006 schwab@suse.de
- Fix off-by-one in add_symbol_file_command [#200831].
* Fri Aug 11 2006 schwab@suse.de
- Correctly extend addresses read from link map.
* Sun Jul 16 2006 schwab@suse.de
- Fix function decriptor handing on ppc64.
* Wed Jun 21 2006 schwab@suse.de
- Update to final gdb 6.5.
* Thu Jun  8 2006 schwab@suse.de
- Avoid an unlikely buffer overflow [#175149].
* Sat Jun  3 2006 schwab@suse.de
- Update to gdb 6.5 RC 1.
* Wed May 31 2006 schwab@suse.de
- Set long double size to 16 [#180103].
* Fri May 26 2006 schwab@suse.de
- Fix locating dynamic linker breakpoint on ppc64 [#177323].
* Mon May 22 2006 schwab@suse.de
- Update to gdb 6.4.90 snapshot 20060522.
* Mon May 22 2006 schwab@suse.de
- Don't ignore symbols for solib trampolines.
* Sun Apr 23 2006 schwab@suse.de
- Add patch to avoid losing compilation directory.
- Fix a parallel build problem.
* Tue Apr  4 2006 schwab@suse.de
- Relocate PIEs.
* Sun Mar 26 2006 schwab@suse.de
- Handle .eh_frame register encoding that is different from .dwarf_frame.
- Remove obsolete patch.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jan 23 2006 schwab@suse.de
- Add fix for PIC prologue analyzer on powerpc.
* Wed Dec 14 2005 schwab@suse.de
- Add fix for observer notify queue after attach.
* Fri Dec  2 2005 schwab@suse.de
- Update to gdb 6.4.
* Tue Nov 22 2005 schwab@suse.de
- Update to gdb 6.3.90.
* Fri Nov  4 2005 schwab@suse.de
- Update to gdb-6.3.50 snapshot 20051103.
* Mon Oct  3 2005 schwab@suse.de
- Update to gdb 6.3.50 snapshot 20051003.
* Mon Sep 19 2005 schwab@suse.de
- Fix warnings.
* Sun Aug 21 2005 schwab@suse.de
- Add DWARF CFI unwinder on ppc.
* Mon Jun 20 2005 schwab@suse.de
- Require libunwind-devel on ia64.
* Thu Jun  9 2005 schwab@suse.de
- Add patch for ia64 vDSO support and unwinding through signals and
  syscalls [#60766].
* Mon Apr 11 2005 schwab@suse.de
- Fix backtrace through vsyscall [#63483].
* Sun Apr 10 2005 schwab@suse.de
- Add patch to fix bugs in rs6000/powerpc register set functions.
- Fix a testsuite bug.
* Sun Mar  6 2005 schwab@suse.de
- Add patch to suppress fork attach/detach messages.
* Wed Mar  2 2005 schwab@suse.de
- Add patch to fix following vfork from a secondary thread.
* Mon Feb 28 2005 schwab@suse.de
- Don't ignore DW_TAG_member [#66406].
* Tue Feb  1 2005 schwab@suse.de
- Find separate debug symbol files in /usr/lib/debug by default.
* Thu Jan 27 2005 schwab@suse.de
- Add patch to handle back-to-back and nested signals.
* Thu Jan 27 2005 schwab@suse.de
- Add patch to implement reggroups for ppc.
* Wed Jan 26 2005 schwab@suse.de
- Add patch to implement PPC GNU/Linux sigtramp frame code.
* Wed Jan 12 2005 schwab@suse.de
- Don't error out when encountering an unavailable value.
* Fri Dec  3 2004 schwab@suse.de
- Downgrade errors to warnings during backtrace [#48484].
- Undocument --readnever since it may not be supported by future releases.
- Fix patches from last change.
* Fri Dec  3 2004 kukuk@suse.de
- Add --readnever option as workaround for [#48485]
* Sun Nov 14 2004 schwab@suse.de
- Add libunwind-devel to neededforbuild.
* Sat Nov 13 2004 schwab@suse.de
- Fix missing dependencies.
* Wed Nov 10 2004 schwab@suse.de
- Version 6.2.91 renamed to 6.3.
* Mon Nov  8 2004 schwab@suse.de
- Update to gdb 6.2.91 (6.3 release candidate).
* Mon Nov  8 2004 schwab@suse.de
- Revert last change.
- Fix typo.
* Mon Nov  8 2004 uli@suse.de
- fixed to build on s390*
* Mon Oct 25 2004 schwab@suse.de
- Fix building gdbserver on x86-64.
* Mon Oct 25 2004 schwab@suse.de
- Update to gdb 6.2.90.
- Use libunwind on ia64.
* Thu Sep  9 2004 schwab@suse.de
- Update to gdb 6.2.1.
* Wed Aug 25 2004 schwab@suse.de
- Fix deadlock in child_wait [#42796].
* Tue Aug 24 2004 schwab@suse.de
- Import latest changes from 6.2 branch.
* Fri Jul 30 2004 schwab@suse.de
- Update to gdb 6.2.
* Thu Jul 29 2004 schwab@suse.de
- Update to gdb 6.1.92.
* Mon Jul 26 2004 schwab@suse.de
- Fix handling of relative filenames in DWARF2 .debug_line.
* Mon Jul 19 2004 schwab@suse.de
- Update to gdb 6.1.91.
* Thu Jun 24 2004 schwab@suse.de
- Better handling of dying threads.
* Fri Jun 18 2004 schwab@suse.de
- Update to gdb 6.1.1.
* Tue May 25 2004 schwab@suse.de
- Fix handling of short lived threads [#40841].
* Sat May  1 2004 schwab@suse.de
- Restore removed hunk.
* Fri Apr 30 2004 meissner@suse.de
- applied 3 patches to fix problems on ppc64. #39394
* Sat Apr 17 2004 schwab@suse.de
- Pacify autobuild.
* Mon Apr  5 2004 schwab@suse.de
- Version 6.0.92 has been renamed to 6.1.
* Sat Apr  3 2004 schwab@suse.de
- Update to gdb 6.0.92 (6.1 release candidate).
* Tue Mar 30 2004 schwab@suse.de
- Fix invalid use of va_list.
* Mon Mar 29 2004 schwab@suse.de
- Update to gdb 6.0.91.
* Mon Mar 29 2004 schwab@suse.de
- Update to current CVS.
* Fri Mar 19 2004 schwab@suse.de
- Fix last change: don't disable testsuite.
* Wed Mar 17 2004 mludvig@suse.cz
- Added opcodes for VIA PadLock instructions.
* Tue Mar  2 2004 schwab@suse.de
- Update to gdb 6.0.90.
- Run testsuite.
* Thu Jan  8 2004 schwab@suse.de
- Fix gate area range.
* Wed Dec 10 2003 schwab@suse.de
- Support DW_TAG_subrange_type.
- Backport recent ia64 improvements from mainline.
* Tue Oct 21 2003 mludvig@
- Add support for debugging both i386 and amd64 apps by a single
  amd64 GDB binary.
* Mon Oct 20 2003 mludvig@suse.cz
- Correctly interpret symbol tables for debugging kernel modules
  (gdb6-symtab-minimal.diff)
- Fixed support for GCC variable tracking (gdb6-vartrack.diff)
- Fixed support for Fortran arrays (gdb6-fortranarray.diff)
* Tue Oct  7 2003 schwab@suse.de
- Hack to build on sparc.
* Mon Oct  6 2003 schwab@suse.de
- Update to gdb 6.0.
* Fri Oct  3 2003 kukuk@suse.de
- Remove unused tetex from neededforbuild
* Mon Sep 29 2003 schwab@suse.de
- Update to gdb 5.3.93 pre-release.
* Wed Sep 17 2003 schwab@suse.de
- Remove debugging hooks.
* Wed Sep 17 2003 schwab@suse.de
- Ignore more insns during i386 prologue decoding [#30288].
- Fix hash table mixup in bfd_simple interface.
* Tue Sep 16 2003 schwab@suse.de
- Update to gdb 5.3.92 pre-release.
  * Fixes bug 31033.
* Wed Sep  3 2003 schwab@suse.de
- Update to gdb 5.3.91 pre-release.
* Tue Aug 19 2003 schwab@suse.de
- Update to gdb 5.3.90 2003-08-19 cvs snapshot.
* Mon Jun 23 2003 kukuk@suse.de
- Fix compiling on SPARC
* Tue Jun 10 2003 schwab@suse.de
- Don't package mmalloc.info, since libmmalloc isn't included either.
* Thu May 15 2003 schwab@suse.de
- Remove unwanted files.
* Thu Apr 24 2003 ro@suse.de
- fix install_info --delete call and move from preun to postun
* Fri Apr 11 2003 mludvig@suse.cz
- Fix read_2u() function in dwarf2cfi.c
* Thu Apr 10 2003 mludvig@suse.cz
- Add 'info cfi <address>' command.
- Fix off-by-4 bug in the CFI parser.
* Mon Apr  7 2003 schwab@suse.de
- Only delete info entries when removing last version.
* Thu Mar 27 2003 schwab@suse.de
- Fix specfile.
* Thu Mar  6 2003 aj@suse.de
- Fix neededforbuild.
* Wed Feb 26 2003 mludvig@suse.cz
- Added loclist support
- Fixed eh_frame parsing problems
- Updated for proposed x86-64 ABI change
* Thu Feb  6 2003 schwab@suse.de
- Use %%install_info.
* Tue Feb  4 2003 schwab@suse.de
- Enable TUI.
* Sun Jan 26 2003 olh@suse.de
- add inital native ppc64 support
* Thu Jan  9 2003 mludvig@suse.cz
- Fixed compilation problem with last gdb-asmbtrace.diff.
  No new feature.
* Tue Jan  7 2003 mludvig@suse.cz
- Several Dwarf2 and x86-64 specific changes
  * Added ability to do backtrace from some functions
    without debug info (patch gdb-asmbtrace.diff)
  * Fixed crash on re-run of a debugged program.
  * Added some more verbosity to dwarf2cfi engine.
* Thu Dec 12 2002 schwab@suse.de
- Update to gdb 5.3.
  * GNU/Linux shared library multi-threaded performance improved.
  * ``gdbserver'' now supports multi-threaded applications on some targets
  * GDB now supports C/C++ preprocessor macros.
* Fri Oct 11 2002 aj@suse.de
- Handle gcc code generated by gcc -f-elimante-dwarf2-dups -g.
* Thu Sep 26 2002 schwab@suse.de
- Avoid installing libbfd, libopcodes, libiberty and libmmalloc [#20199].
* Wed Sep 18 2002 sf@suse.de
- added patch from mludvig to remove framepointer on x86_64
* Wed Sep  4 2002 kukuk@suse.de
- Add Patch for reading SPARC core files
* Tue Sep  3 2002 schwab@suse.de
- Remove tetex from neededforbuild.
* Wed Jul 24 2002 schwab@suse.de
- Update to gdb 5.2.1.
* Thu Jul 18 2002 mludvig@suse.de
- Fix PLT recognisation.
* Mon Jul  8 2002 schwab@suse.de
- Add fix for memory leak.
* Tue Jul  2 2002 mludvig@suse.cz
- removed my previous patches
- added a huge one suse-521-x8664.diff
* Thu Jun  6 2002 sf@suse.de
- added fpregset.diff (from mludvig@suse.de)
- added dwarf2cfi.diff (from mludvig@suse.de)
* Wed May 15 2002 sf@suse.de
- added some dwarf2-patches for x86_64
  (from mludvig@suse.de)
* Thu May  9 2002 schwab@suse.de
- Fix breakpoints on MLX bundle.
* Mon May  6 2002 schwab@suse.de
- Sparc doesn't have gdbserver either.
* Sun May  5 2002 schwab@suse.de
- Update to gdb 5.2.
- Gdbserver now available for all but alpha.
* Fri Jan 25 2002 schwab@suse.de
- Update to gdb 5.1.1.
* Thu Nov 22 2001 schwab@suse.de
- Update to gdb 5.1.
- Build and install gdbserver on i386 and ia64.
* Sat Aug 18 2001 schwab@suse.de
- Update to gdb snapthot 20010316.
* Fri May 18 2001 schwab@suse.de
- Include ia64 warning patches (from nadvornik@suse.cz).
* Thu Apr 12 2001 schwab@suse.de
- Remove declaration of tilde_expand, now in readline header.
* Sat Mar 31 2001 schwab@suse.de
- Fix hardware watchpoints on ia64.
* Fri Mar 30 2001 schwab@suse.de
- Fix crash on info architecture (#6865).
* Wed Mar 28 2001 schwab@suse.de
- Use installed readline library.
* Tue Mar  6 2001 schwab@suse.de
- Remove some ia64 hacks.
* Tue Dec 12 2000 schwab@suse.de
- Improve handling of breakpoints in shared libraries.
* Fri Nov 17 2000 kukuk@suse.de
- Update to working gdb snapshot
* Wed Sep 27 2000 fober@suse.de
- s390: added s390-sigregs-SuSE.patch
* Thu Sep 14 2000 fober@suse.de
- s390: incorporate new ibm patches for gdb 5.0
* Wed Sep  6 2000 fober@suse.de
- s390: incorporate ibm patches for gdb 5.0
* Fri Jun 30 2000 kukuk@suse.de
- Add gdb-5.0
* Tue Apr  4 2000 bk@suse.de
- s390 team added s390 support
* Tue Mar 21 2000 schwab@suse.de
- Fix core dump reading (#2586).
* Fri Feb  4 2000 kukuk@suse.de
- Add patches for PPC
- Move /usr/info -> /usr/share/info
* Mon Dec  6 1999 kukuk@suse.de
- Remove gdb 4.17
- Add gdb 4.18 fixes for SPARC
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Fri Sep  3 1999 kukuk@suse.de
- Use RPM values for CFLAGS and configure
* Tue Aug 24 1999 uli@suse.de
- added -fsigned-char to CFLAGS (PPC)
* Mon Aug 23 1999 kukuk@suse.de
- Add gdb 4.18 thread patch from RH
* Mon Jul 19 1999 florian@suse.de
- add gdb-4.17.0.12 as /usr/bin/gdb-4.17
* Wed Jul  7 1999 kukuk@suse.de
- update to 4.18 using diff from jurix
* Mon Feb 22 1999 ro@suse.de
- update to 4.17.0.11 using diff from jurix
* Thu Jan 21 1999 ro@suse.de
- update to 4.17.0.8
* Thu Oct  1 1998 ro@suse.de
- update to 4.17.0.4 using jurix-diff
* Tue Sep 15 1998 ro@suse.de
- hacked for GLIBC: include sys/ucontext and sys/ptrace where needed
- catch strup redeclarations
- cleaned up patch-sequence
* Tue Oct 28 1997 florian@suse.de
- fix <sys/procfs.h> in libc to correctly support core-files
- add bug-fix to read symbols from dynamic symbol tables
- apply all patches from debian gdb-4.16-11
* Thu Jan  2 1997 florian@suse.de
  Neue Version 4.16.
  gdb kompiliert nur mit libc 5.4.7 richtig. Mit 5.2.18 kann gdb
  keine core-files lesen.
  Ich waere dafuer, einfach das Binary von libc 5.4.7 zu benutzen.
  Wird schon funktionieren...
